==> camitk_3.3.2.orig.tar.gz: camitk-3.3.2-Source/sdk/applications/wizard/CepCreateOrModifyWidget.cpp <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/

// Include .h file
#include "CepCreateOrModifyWidget.h"

// Qt files
#include <QMessageBox>

/**  Constructor */
CepCreateOrModifyWidget::CepCreateOrModifyWidget(QWidget * parent) : QWidget(parent)
{
    ui.setupUi(this);
    ui.createRadioButton->setChecked(true);
}
/**  Destructor */
CepCreateOrModifyWidget::~CepCreateOrModifyWidget() {}

void CepCreateOrModifyWidget::nextButtonClicked()
{
    if (ui.createRadioButton->isChecked())
    {
        emit newCep();
    }
    else
    {
        QMessageBox::warning(this, "Feature not implemented", "This feature is not implemented yet, sorry...\n");
        ui.createRadioButton->setChecked(true);
        emit existingCep();
    }
}

void CepCreateOrModifyWidget::backButtonClicked()
{
    emit backCep();
}

==> camitk_3.4.0.orig.tar.gz: camitk-3.4.0-Source/sdk/applications/wizard/CepCreateOrModifyWidget.cpp <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/

// Include .h file
#include "CepCreateOrModifyWidget.h"

// Qt files
#include <QMessageBox>

/**  Constructor */
CepCreateOrModifyWidget::CepCreateOrModifyWidget(QWidget * parent) : QWidget(parent) {
    ui.setupUi(this);
    ui.createRadioButton->setChecked(true);
}
/**  Destructor */
CepCreateOrModifyWidget::~CepCreateOrModifyWidget() {}

void CepCreateOrModifyWidget::nextButtonClicked() {
    if (ui.createRadioButton->isChecked()) {
        emit newCep();
    } else {
        QMessageBox::warning(this, tr("Feature not implemented"), tr("This feature is not implemented yet, sorry...\n"));
        ui.createRadioButton->setChecked(true);
        emit existingCep();
    }
}

void CepCreateOrModifyWidget::backButtonClicked() {
    emit backCep();
}
